# User guide

This user guide provides instructions, examples, and explanations to help you effectively use Visisipy for simulating and analyzing visual systems.

Refer to the sections below to learn about installation, normal simulation workflow, and advanced usage. 

:::{tip}
Most sections in this user guide are Jupyter notebooks. You can download them using the {fa}`download` `Download notebook` link in the 
right sidebar.
:::

```{toctree}
:maxdepth: 2
:caption: Getting started

installation
example
```

```{toctree}
:maxdepth: 2
:caption: Simulation workflow

eye_models
backend
analyses
```

```{toctree}
:maxdepth: 2
:caption: Advanced usage

backend_direct
backend_multiple
custom_surfaces
```
